@@ -1,4 +1,5 @@
 # Copyright (C) 2013-2016 DNAnexus, Inc.
+# -*- coding: utf-8 -*-
 #
 # This file is part of dx-toolkit (DNAnexus platform client libraries).
 #
@@ -39,7 +40,7 @@ UPDATABLE_GLOBALWF_FIELDS = {'title', 'summary', 'description', 'developerNotes'
 GLOBALWF_SUPPORTED_KEYS = UPDATABLE_GLOBALWF_FIELDS.union({"name", "version", "regionalOptions",
                                                            "categories", "billTo", "dxapi", "tags"})
 SUPPORTED_KEYS = GLOBALWF_SUPPORTED_KEYS.union({"project", "folder", "outputFolder", "stages",
-                                                "inputs", "outputs", "ignoreReuse"})
+                                                "inputs", "outputs", "ignoreReuse", "properties"})
 
 class WorkflowBuilderException(Exception):
     """
@@ -68,18 +69,6 @@ def _fetch_spec_from_dxworkflowjson(src_dir, json_file_name, parser):
         except Exception as e:
             raise WorkflowBuilderException("Could not parse {} file as JSON: {}".format(json_file_name, e.args))
 
-
-def _fetch_spec_from_workflow(args, parser):
-    try:
-        source_workflow = dxpy.DXWorkflow(args._from)
-        json_spec = source_workflow.describe(fields={"properties", "details"}, default_fields=True)
-        json_spec = _cleanup_empty_keys(json_spec)
-
-    except Exception as e:
-        raise WorkflowBuilderException("Could not get specs from given workflow {}: {}".format(args._from, e.args))
-
-    return json_spec
-
 def _cleanup_empty_keys(json_spec):
     import re
     clean_json = re.sub('\"\w*\": (null|\{\}|\"\"|\[\])(\,|)\s*','',json.dumps(json_spec)).replace(", }","}")
@@ -105,7 +94,7 @@ def _notify_instance_type_selection(json_spec):
 
 def _notify_dependencies(json_spec):
     # APPS-622: A textual representation of all the dependencies is appended to 
-    # the “description” field of every workflow generated by the dxCompiler in markdown format.
+    # the "description" field of every workflow generated by the dxCompiler in markdown format.
      dependency_list = json_spec.get("description")
      if dependency_list:
          print("Note: {workflow} was compiled with unbundled dependencies. "
@@ -520,7 +509,10 @@ def _build_underlying_workflows(enabled_regions, json_spec, args):
 
     try:
         for region, project in projects_by_region.items():
+            # Override workflow project ID and folder in workflow spec 
+            # when building underlying workflow in temporary project
             json_spec['project'] = project
+            json_spec['folder'] = '/'
             workflow_id = _build_regular_workflow(json_spec)
             logger.debug("Created workflow " + workflow_id + " successfully")
             workflows_by_region[region] = workflow_id
@@ -641,7 +633,7 @@ def _build_or_update_workflow(args, parser):
             workflow_id = _build_regular_workflow(json_spec, args.keep_open)
         elif args.mode == 'globalworkflow':
             if args._from:
-                json_spec = _fetch_spec_from_workflow(args, parser)
+                json_spec = args._from
             else:
                 json_spec = _fetch_spec_from_dxworkflowjson(args.src_dir, "dxworkflow.json", parser)
             
@@ -659,6 +651,7 @@ def _build_or_update_workflow(args, parser):
                     _notify_instance_type_selection(json_spec)
                     _notify_dependencies(json_spec)
             
+            json_spec = _cleanup_empty_keys(json_spec)
             # Verify if the global workflow already exists and if the user has developer rights to it
             # If the global workflow name doesn't exist, the user is free to build it
             # If the name does exist two things can be done:
